#!/bin/bash
#
# NAME:
#	sb-status
#
# SYNOPSIS:
#
#	sb-status
#
# DESCRIPTION:
#	Report Secure Boot status.
#
# AUTHOR:
#	dzeng@juniper.net
#
# Copyright (c) 2015, Juniper Networks, Inc.
#

Error () {
	echo "Error: $@" >&2
	echo "secure boot status is unknown"
	exit 1
}

# Where EFI varfs is mounted to
EFIVARFS=${EFIVARFS:-/sys/firmware/efi/efivars}

# SecureBoot variable
SECUREBOOT=${SECUREBOOT:-SecureBoot-8be4df61-93ca-11d2-aa0d-00e098032b8c}

# SecureBootEnforce variable
SECUREBOOTENFORCED=${SECUREBOOTENFORCED:-SecureBootEnforce-59d1c24f-50f1-401a-b101-f33e0daed443}

find_or_mount_efivarfs() {
	# check whether efivarfs is supported
	grep -w -q efivarfs /proc/filesystems || Error "efivarfs is not supported"

	mount -l | awk '{print $1}' | grep -w -q efivarfs
	if [ $? -eq 0 ]; then
		# already mounted
		EFIVARFS=`mount -l | awk '$1 == "efivarfs" {print $3}'`
		test -d "${EFIVARFS}" || Error "failed to find mounted efivarfs"
	else
		# mount efivarfs, if not mounted
		[ -d $EFIVARFS ] || mkdir -p $EFIVARFS || Error "$EFIVARFS directory does not exist"
		mount -t efivarfs $EFIVARFS $EFIVARFS || Error "failed mount efivarfs on $EFIVARFS"
	fi
}

# mount efivarfs, if not mounted
find_or_mount_efivarfs

# check secure boot status
sb_status=$(dd if=${EFIVARFS}/${SECUREBOOT} bs=1 skip=4 2>/dev/null | od -t x1 | awk '{print $2}')
sbe_status=$(dd if=${EFIVARFS}/${SECUREBOOTENFORCED} bs=1 skip=4 2>/dev/null | od -t x1 | awk '{print $2}')

if [ "$sb_status" == '01' -a "$sbe_status" == '01' ] ; then
  echo "Secure Boot is enforced."
  exit 0
elif [ "$sb_status" == '00' -o "$sbe_status" == '00' ] ; then
  echo "Secure Boot is either not enabled or not enforced."
  exit -1
else
  Error "Secure Boot status is unknown"
fi
